Radius

Struct Radius 

pub struct Radius {
    pub top_left: f32,
    pub top_right: f32,
    pub bottom_right: f32,
    pub bottom_left: f32,
}
The border radii for the corners of a graphics primitive in the order: top-left, top-right, bottom-right, bottom-left.

Fields

top_left: f32

Top left radius

top_right: f32

Top right radius

bottom_right: f32

Bottom right radius

bottom_left: f32

Bottom left radius

Implementations

Source

impl Radius

pub fn new(value: impl Into<Pixels>) -> Self

Creates a new Radius with the same value for each corner.

pub fn top_left(self, value: impl Into<Pixels>) -> Self

Sets the top left value of the Radius.

pub fn top_right(self, value: impl Into<Pixels>) -> Self

Sets the top right value of the Radius.

pub fn bottom_right(self, value: impl Into<Pixels>) -> Self

Sets the bottom right value of the Radius.

pub fn bottom_left(self, value: impl Into<Pixels>) -> Self

Sets the bottom left value of the Radius.

pub fn top(self, value: impl Into<Pixels>) -> Self

Sets the top left and top right values of the Radius.

pub fn bottom(self, value: impl Into<Pixels>) -> Self

Sets the bottom left and bottom right values of the Radius.

pub fn left(self, value: impl Into<Pixels>) -> Self

Sets the top left and bottom left values of the Radius.

pub fn right(self, value: impl Into<Pixels>) -> Self

Sets the top right and bottom right values of the Radius.